@@ -34,6 +34,8 @@ int c_set_window_geometry2(lua_State *lua);
 
 int c_set_window_size(lua_State *lua);
 
+int c_set_window_strut(lua_State *lua);
+
 int c_make_always_on_top(lua_State *lua);
 
 int c_set_on_top(lua_State *lua);
@@ -65,6 +67,8 @@ int c_unpin_window(lua_State *lua);
 int c_stick_window(lua_State *lua);
 int c_unstick_window(lua_State *lua);
 
+int c_close_window(lua_State *lua);
+
 void set_current_window(WnckWindow *window);
 WnckWindow *get_current_window();
 
@@ -108,4 +112,6 @@ int c_get_screen_geometry(lua_State *lua);
 
 int c_focus(lua_State *lua);
 
+int c_get_window_fullscreen(lua_State *lua);
+
 #endif /*__HEADER_SCRIPT_FUNCTIONS_*/
